import { CfnTag, Duration } from 'aws-cdk-lib';
import * as cloud9 from 'aws-cdk-lib/aws-cloud9';
import { IRepository } from 'aws-cdk-lib/aws-codecommit';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
export declare enum Cloud9ConnectionType {
    /** This method accesses the environment using SSH and requires open inbound ports */
    SSH = "CONNECT_SSH",
    /** This method accesses the environment using SSM (Sytems Manager) without opening inbound ports. */
    SSM = "CONNECT_SSM"
}
export declare enum Cloud9AmiType {
    /**
     * Amazon Linux 2 AMI (recommended)
     * @link https://aws.amazon.com/amazon-linux-2/
     * */
    AMZN_LINUX_2 = "resolve:ssm:/aws/service/cloud9/amis/amazonlinux-2-x86_64",
    /**
     * Ubuntu 22.04 LTS - Jammy Jellyfish
     * @link https://aws.amazon.com/amazon-linux-2/
     * */
    UBUNTU_22_04 = "resolve:ssm:/aws/service/cloud9/amis/ubuntu-22.04-x86_64",
    /**
     * Amazon Linux 1.
     * - For new deployments prefer `AMZN_LINUX_2`
     * */
    AMZN_LINUX_1 = "resolve:ssm:/aws/service/cloud9/amis/amazonlinux-1-x86_64",
    /**
     * Ubuntu 18.04 LTS - Bionic Beaver.
     * For new deployments prefer `UBUNTU_22_04`
     * */
    UBUNTU_18_04 = "resolve:ssm:/aws/service/cloud9/amis/ubuntu-18.04-x86_64"
}
export interface RepositoryCloneProps {
    readonly repositoryUrl: string;
    readonly environmentPath: string;
}
export interface Cloud9EnvironmentProps {
    /**
     * The amount of time to wait for the environment to stop.
     * @default - 30 minutes
     */
    readonly automaticStopTime?: Duration;
    /**
     * The type of EC2 instance to use.
     * @default - t3.small
     */
    readonly instanceType?: ec2.InstanceType;
    /**
     * The type of connection method to use.
     * @default Cloud9ConnectionType.SSM
     */
    readonly connectionType: Cloud9ConnectionType;
    /**
     * The name of the environment.
     * @default - A Cloud9 -generated
     */
    readonly name?: string;
    /**
     * The description of the environment.
     * @default - None
     */
    readonly description?: string;
    /**
     * The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance.
     * @default - Cloud9AmiType.AMZN_LINUX_2
     */
    readonly imageId?: Cloud9AmiType;
    /**
     * The Amazon Resource Name (ARN) of the environment owner.
     * @default - "This environment creator (careful, this might be the CloudFormation role!)"
     */
    readonly ownerArn?: string;
    /**
     * The subnet to use for the environment.
     */
    readonly subnet?: ec2.ISubnet;
    /**
     * The tags to apply to the environment.
     */
    readonly tags?: Array<CfnTag>;
}
/**
 * The type of access to grant to collaborators of the environment
 */
export declare enum CollaboratorAccessType {
    /** Grants read-only access to the environment. */
    READ_ONLY = "read-only",
    /** Grants read-write access to the environment. */
    READ_WRITE = "read-write"
}
/**
 * A Cloud 9 Environment with bootstrapping capabilities leveraging SSM automation.
 */
export declare class Cloud9Environment extends Construct {
    private readonly _repositories;
    /** The underlying CfnEnvironmentEC2 L1 resource. */
    readonly resource: cloud9.CfnEnvironmentEC2;
    /** The HTTPS URL of the Cloud9 environment from which it can be accessed. */
    readonly environmentUrl: string;
    /** The ID of the Cloud9 environment. (e.g. `0e19f1e459a44006a1ef37222561bcc6`)*/
    readonly environmentId: string;
    /** The ARN of the Cloud9 environment, useful for limiting IAM policies. */
    readonly environmentArn: string;
    /** The ID of the underlying EC2 instance (e.g. `i-0cdc52635e6b51069`) */
    readonly instanceId: string;
    /** The security group of the underlying EC2 instance. By default, SSM only allows outbound traffic.*/
    readonly securityGroup: ec2.ISecurityGroup;
    /** The private IP address of the underlying EC2 instance (e.g. `172.31.39.167`)*/
    readonly privateIp: string;
    /** The volume identifier of the underlying EBS volume in the instance (e.g. `vol-0d1fadbf56e20a86e`) */
    readonly volumeId: string;
    /** The IAM Role associated to this environment @default AWSCloud9SSMAccessRole */
    readonly instanceRole: IRole;
    /** The default path within the Cloud9 environment: @default /home/ec2-user/environment */
    readonly defaultEnvironmentPath: string;
    private _steps;
    private _document;
    constructor(scope: Construct, id: string, props: Cloud9EnvironmentProps);
    /**
     * Clones a Code Commit repository into the Cloud9 environment.
     * @param repository the CodeCommit repository
     * @param environmentPath the path within Cloud9 where it will be cloned
     */
    cloneCodeCommitRepo(repository: IRepository, environmentPath: string): void;
    /**
     * Clones a public GitHub repository into the Cloud9 environment.
     * @param repositoryUrl  the HTTPS URL of the repository
     * @param environmentPath  the path within Cloud9 where it will be cloned
     */
    cloneGitRepo(repositoryUrl: string, environmentPath: string): void;
    /**
     * Adds bash commands to the Cloud9 environment initialization script.
     * Commands such as `yum install <package>` should include the sudo prefix.
     * @param commands bash commands to execute in the Cloud9 environment
     */
    addInitCommands(commands: string[]): void;
    /**
     * Gives access to collaborators to the Cloud9 environment.
     * @param userArn the ARN of the user to give access
     * @param accessType (optional) the type of access to give, default: `CollaboratorAccessType.READ_WRITE`
     */
    grantCollaboratorAccess(userArn: string, accessType?: CollaboratorAccessType): void;
    /**
     * Resizes the EBS volume attached to the Cloud9 environment.
     * @param size The volume size, in Gibibytes (GiB)
     */
    resizeEbsVolumeTo(size: number): void;
}
